.. _isomorphism:

***********
Isomorphism
***********

.. toctree::
   :maxdepth: 2

Approximate Isomorphism
=======================
.. automodule:: networkx.algorithms.isomorphism.isomorph
.. currentmodule:: networkx
.. autosummary::
   :toctree: generated/

   graph_could_be_isomorphic
   fast_graph_could_be_isomorphic
   faster_graph_could_be_isomorphic
   is_isomorphic


VF2 Algorithm
=============
.. automodule:: networkx.algorithms.isomorphism.isomorphvf2
.. currentmodule:: networkx
.. autosummary::
   :toctree: generated/

   GraphMatcher
   DiGraphMatcher
